==> qmmp-plugin-pack-1.5.0.tar.bz2: qmmp-plugin-pack-1.5.0/src/Engines/ffvideo/translations/ffvideo_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>FFmpeg-videoplug-in</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Videobestanden</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>Over FFVideo-plug-in</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Een op FFmpeg gebaseerde videoplug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Gebouwd met</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Audiobitsnelheid</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Audiosamplesnelheid</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Audiokanalen</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Videogrootte</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Videobitsnelheid</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>FFmpeg-video</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeren</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Spatiebalk</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>Beeld&amp;vullend</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.5.3.tar.bz2: qmmp-plugin-pack-1.5.3/src/Engines/ffvideo/translations/ffvideo_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>FFVideoFactory</name>
    <message>
        <location filename="../ffvideofactory.cpp" line="42"/>
        <source>FFmpeg Video Plugin</source>
        <translation>FFmpeg-videoplug-in</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="46"/>
        <source>Video Files</source>
        <translation>Videobestanden</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="155"/>
        <source>About FFVideo Plugin</source>
        <translation>Over FFVideo-plugpin</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="156"/>
        <source>FFmpeg-based video plugin for Qmmp</source>
        <translation>Een op FFmpeg gebaseerde videoplug-in voor Qmmp</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="157"/>
        <source>Compiled against:</source>
        <translation>Gebouwd met</translation>
    </message>
    <message>
        <location filename="../ffvideofactory.cpp" line="167"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFVideoMetaDataModel</name>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <source>Audio bitrate</source>
        <translation>Audio bitrate</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Audio sample rate</source>
        <translation>Audiosamplesnelheid</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="50"/>
        <source>KiB</source>
        <translation>KiB</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="51"/>
        <location filename="../ffvideometadatamodel.cpp" line="70"/>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="71"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="72"/>
        <source>Audio channels</source>
        <translation>Audiokanalen</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="78"/>
        <source>Video size</source>
        <translation>Videogrootte</translation>
    </message>
    <message>
        <location filename="../ffvideometadatamodel.cpp" line="79"/>
        <source>Video bitrate</source>
        <translation>Video bitrate</translation>
    </message>
</context>
<context>
    <name>VideoWindow</name>
    <message>
        <location filename="../videowindow.cpp" line="40"/>
        <source>FFmpeg Video</source>
        <translation>FFmpeg-video</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pauze</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="45"/>
        <source>Space</source>
        <translation>Spatie</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>&amp;Stop</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="46"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Volledig scherm</translation>
    </message>
    <message>
        <location filename="../videowindow.cpp" line="48"/>
        <source>F</source>
        <translation>F</translation>
    </message>
</context>
</TS>
